@@ -84,7 +84,7 @@
 #define KWALLET_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWALLET_NO_DEPRECATED
-#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KWALLET_NO_DEPRECATED_WARNINGS
 #  define KWALLET_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWALLET_DEPRECATED_WARNINGS_SINCE KWALLET_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define KWALLET_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
